<?php

namespace WPPOOL\SCF;

if (!class_exists('\WPPOOL\SCF\Hooks')) :
	class Hooks
	{
		use \WPPOOL\SCF\Common;
		// Register hooks
		public function __construct()
		{
			add_action('wp_enqueue_scripts', array($this, 'wp_enqueue_scripts'));
			add_action('wp_footer', array($this, 'add_scf_contact_form_to_footer'), 99);
			add_action('wp_ajax_scf_submit_form', array($this, 'scf_submit_form'));
			add_action('wp_ajax_nopriv_scf_submit_form', array($this, 'scf_submit_form'));
		}


		// Enqueue scripts on frontend
		public function wp_enqueue_scripts()
		{
			$scf = scf_get_options();

			$is_enabled = $scf['enabled'] ?? false;

			if (scf_is_true($is_enabled)) {
				wp_enqueue_style('scf-frontend', SCF_PUBLIC . '/css/frontend.min.css', time());
				wp_enqueue_script('scf-frontend', SCF_PUBLIC . '/js/frontend.min.js', array('jquery'), time(), true);
				wp_localize_script(
					'scf-frontend',
					'_scf',
					apply_filters('scf_localize_script', array(
						'ajax_url' => admin_url('admin-ajax.php'),
						'nonce'    => wp_create_nonce('scf_submit_form'),
						'is_pro'   => is_scf_ultimate(),
						'options'  => $scf,
						'development' => scf_is_dev(),
						'tags' => apply_filters('scf_tags', [
							'title' => get_the_title(),
							'url' => get_permalink(),
							'id' => get_the_ID(),
						]),
					))
				);

				// Add inline style
				$inline_style = $this->get_inline_style($scf);
				if (!empty($inline_style)) {
					wp_add_inline_style('scf-frontend', $inline_style);
				}
			}
		}


		# get inline style
		public function get_inline_style($scf = null)
		{
			if (!$scf) {
				$scf = scf_get_options();
			}
			$css = '';

			if (isset($scf['custom_css'])) {
				$css .= $scf['custom_css'];
			}

			// customizable 
			$font = $scf['form']['font'] ?? '';


			$font_url = SCF_PUBLIC . '/fonts/' . (str_replace(' ', '+', $font)) . '.ttf';

			$fontFamily = $this->formatFont($font);
			$premium_fonts = App::premium_fonts();

		
			if (in_array($font, $premium_fonts)) {
				$font_url = SCF_PUBLIC . '/fonts/' . (str_replace(' ', '+', $font)) . '-Regular.ttf';

				$css .= "
				@font-face {
					font-family: {$fontFamily} !important; 
					src: url({$font_url}) format('ttf') !important;	
					font-style: normal !important;
					font-weight: 400 !important; 
				  }";
 
			}
 
			$css .= "
			:root {
				--form_color: {$scf['form']['color']};
				--form_background: {$scf['form']['background']};
				--cta_color:  {$scf['call_to_action']['color']};
				--cta_background: {$scf['call_to_action']['background']};
				--font_family: {$fontFamily};
			}";


			return $css;
		}

		// Add scf contact form to footer
		function add_scf_contact_form_to_footer()
		{
			$is_enabled = scf_get_option('enabled');

			if (scf_is_true($is_enabled)) {
				global $scf;
				$scf = scf_get_options();
				include_once SCF_TEMPLATE . '/frontend/base.php';
			}
		}


		// sanitized form data
		function sanitize_form_data($data)
		{
			$data = array_map('sanitize_text_field', $data);
			$data = array_map('stripslashes', $data);
			return $data;
		}


		// Ajax action
		public function scf_submit_form()
		{
			$is_enabled = scf_is_true(scf_get_option('enabled'));

			if (!$is_enabled) {
				wp_send_json_error(array('message' => __('Contact form is disabled.', 'social-contact-form')));
				wp_die();
			}
			// // check nonce
			if (!wp_verify_nonce(sanitize_text_field($_REQUEST['nonce']), 'scf_submit_form')) {
				wp_send_json_error(array('message' =>  __('Nonce verification failed', 'social-contact-form')));
				wp_die();
			}

			$input_fields = $this->sanitize_form_data($_REQUEST['fields']);
			$input_meta = $this->sanitize_form_data($_REQUEST['meta']);

			$fields = array();
			if (App::fields()) {
				foreach (App::fields() as $field) {
					$fields[$field['name']] = $input_fields[$field['name']];
				}
			}

			$meta = array_merge($input_meta, $input_meta);

			$fields = apply_filters('scf_form_data', $fields);
			$meta = apply_filters('scf_form_meta', $meta);

			do_action('scf_before_submit', $fields);


			$message_id = Lead::create($fields, $meta);

			do_action('scf_after_submit', $message_id, $fields);

			wp_send_json_success(
				array(
					'message'    => __('Message sent successfully', 'social-contact-form'),
					'message_id' => $message_id,
				)
			);
			wp_die();
		}
	}

	new Hooks();
endif;
